/**
 * @file clock.h
 * @brief Clock Module header
 *
 * Proyecto Smart Watch - Clock
 * Clock module
 *
 * This module is used to configure the
 * different clocks of the MPS432P401R
 *
 * clock.h
 * Module that can be used to configure the clock signals of the
 * MSP432P401R
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 22, 2021
 */

#ifndef INCLUDE_CLOCK_H_
#define INCLUDE_CLOCK_H_

/**
 * @brief Configures clock systems of the MPS432P401R according to connection to MSP432 Launchpad. It sets the following configuration:
 * MCLK: 48MHz (HFXTCLK - Divider = 1)
 * HSMCLK: 24MHz (HFXTCLK - Divider = 2)
 * SMCLK: 12MHz (HFXTCLK - Divider = 4)
 * ACLK: 32768Hz (LFXTCLK - Divider = 1)
 */
void configureClockSystem(void);

#endif /* INCLUDE_CLOCK_H_ */
