/**
 * @file fifo_queue.h
 * @brief Laboratorio 3 - Sistemas Embebidos - Fing
 * 8-BIT FIFO QUEUE MODULE
 *
 * @author Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date 1/4/2021
 */

#ifndef INCLUDE_FIFO_QUEUE_H_
#define INCLUDE_FIFO_QUEUE_H_

/**
* Constants shared with other modules
*/

#define  QUEUE_DIMENSION 20

/**
 * @brief Initializes head and tail
 * @param char* head: modifies head by reference
 * @param char* tail: modifies tail by reference
 */
void initQueue(char *head, char *tail);

/**
 * @brief Indicates if queue is empty
 * @param char head: current value of head pointer
 * @param char tail: current value of tail pointer
 * @return char Outputs 1 if queue is empty
 */
char queueIsEmpty(char head, char tail);

/**
 * @brief Indicates if queue is full
 * @param char head: current value of head pointer
 * @param char tail: current value of tail pointer
 * @return char Outputs 1 if queue is full
 */
char queueIsFull(char head, char tail);

/**
 * @brief Adds char value to queue
 * @param char value: value to be added
 * @param char* head: modifies head by reference
 * @param char* queue: modifies queue by reference
 */
void addToQueue(char value, char *head, char *queue);

/**
 * @brief Returns a char value from the fifo queue
 * @param char* tail: modifies tail by reference
 * @param char* queue: modifies queue by reference
 * @return char value that was stored in the queue
 */
char getFromQueue(char *tail, char *queue);

#endif // INCLUDE_FIFO_QUEUE_H_
